"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const devkit_1 = require("@nx/devkit");
const chalk = require("chalk");
const child_process_1 = require("child_process");
const path_1 = require("path");
const fs_1 = require("fs");
function runBuildExecutor(options, context) {
    return tslib_1.__asyncGenerator(this, arguments, function* runBuildExecutor_1() {
        var _a, e_1, _b, _c;
        const configs = options.runSequence.map((target) => {
            var _a;
            const cfg = (0, devkit_1.parseTargetString)(target, context.projectGraph);
            (_a = cfg.configuration) !== null && _a !== void 0 ? _a : (cfg.configuration = context.configurationName);
            return cfg;
        });
        if (!options.skipTypeCheck) {
            yield tslib_1.__await(runTypeCheck(options, context));
        }
        devkit_1.output.log({
            title: `Building the ${context.projectName} project`,
            bodyLines: [
                '\nTargets to be executed:',
                ...configs.map((t) => chalk.dim((0, devkit_1.targetToTargetString)(t))),
            ],
        });
        for (const target of configs) {
            try {
                const step = yield tslib_1.__await((0, devkit_1.runExecutor)(target, {}, context));
                try {
                    for (var _d = true, step_1 = (e_1 = void 0, tslib_1.__asyncValues(step)), step_1_1; step_1_1 = yield tslib_1.__await(step_1.next()), _a = step_1_1.done, !_a;) {
                        _c = step_1_1.value;
                        _d = false;
                        try {
                            const result = _c;
                            if (!result.success) {
                                yield yield tslib_1.__await({ success: false });
                                return yield tslib_1.__await(void 0);
                            }
                        }
                        finally {
                            _d = true;
                        }
                    }
                }
                catch (e_1_1) { e_1 = { error: e_1_1 }; }
                finally {
                    try {
                        if (!_d && !_a && (_b = step_1.return)) yield tslib_1.__await(_b.call(step_1));
                    }
                    finally { if (e_1) throw e_1.error; }
                }
            }
            catch (error) {
                console.error(error);
                yield yield tslib_1.__await({ success: false });
                return yield tslib_1.__await(void 0);
            }
        }
        yield yield tslib_1.__await({ success: true });
    });
}
exports.default = runBuildExecutor;
function runTypeCheck(options, context) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        let tsFilePath = options.tsConfig && (0, path_1.resolve)(options.tsConfig);
        if (!tsFilePath) {
            const projectConfiguration = context.projectsConfigurations.projects[context.projectName];
            const tsFileName = projectConfiguration.projectType === 'application'
                ? 'tsconfig.app.json'
                : 'tsconfig.lib.json';
            tsFilePath = (0, path_1.resolve)(projectConfiguration.root, tsFileName);
        }
        if (!(0, fs_1.existsSync)(tsFilePath)) {
            const customTsConfigMessage = options.tsConfig
                ? ''
                : ` If project's tsconfig file name is not standard, provide the path to it as "tsConfig" executor option.`;
            throw new Error(`Could not find tsconfig at "${tsFilePath}".` + customTsConfigMessage);
        }
        const typeCheckCommand = `npx tsc --incremental --noEmit --pretty -p ${tsFilePath}`;
        devkit_1.output.log({
            title: `Running type check for the "${context.projectName}"..`,
            bodyLines: [chalk.dim(typeCheckCommand)],
        });
        const exitCode = yield spawnChecker(typeCheckCommand);
        if (exitCode !== 0) {
            process.exit(exitCode);
        }
    });
}
function spawnChecker(typeCheckCommand) {
    return new Promise((r) => {
        const proc = (0, child_process_1.spawn)(typeCheckCommand, {
            cwd: process.cwd(),
            stdio: 'inherit',
            env: process.env,
            // shell is necessary on windows to get the process to even start.
            // Command line args constructed by checkers therefore need to escape double quotes
            // to have them not striped out by cmd.exe. Using shell on all platforms lets us avoid
            // having to perform platform-specific logic around escaping quotes since all platform
            // shells will strip out unescaped double quotes. E.g. shell=false on linux only would
            // result in escaped quotes not being unescaped.
            shell: true,
        });
        proc.on('exit', (code) => {
            if (code !== null && code !== 0) {
                r(code);
            }
            else {
                r(0);
            }
        });
    });
}
//# sourceMappingURL=executor.js.map