"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getQwikApplicationProjectTargets = void 0;
function getQwikApplicationProjectTargets(params) {
    return {
        build: getBuildTarget(params),
        'build.client': getBuildClientTarget(params),
        'build.ssr': getBuildSsrTarget(params),
        preview: getPreviewTarget(params),
        test: getTestTarget(params),
        serve: getServeTarget(params),
        'serve.debug': getServeDebugTarget(params),
    };
}
exports.getQwikApplicationProjectTargets = getQwikApplicationProjectTargets;
function getBuildTarget(params) {
    return {
        executor: 'qwik-nx:build',
        options: {
            runSequence: [
                `${params.projectName}:build.client`,
                `${params.projectName}:build.ssr`,
            ],
            outputPath: `dist/${params.projectRoot}`,
        },
        configurations: {
            preview: {},
        },
    };
}
function getBuildClientTarget(params) {
    return {
        executor: '@nx/vite:build',
        options: {
            outputPath: `dist/${params.projectRoot}`,
            configFile: `${params.projectRoot}/vite.config.ts`,
        },
    };
}
function getBuildSsrTarget(params) {
    return {
        executor: '@nx/vite:build',
        defaultConfiguration: 'preview',
        options: {
            outputPath: `dist/${params.projectRoot}`,
        },
        configurations: {
            preview: {
                ssr: 'src/entry.preview.tsx',
                mode: 'production',
            },
        },
    };
}
function getPreviewTarget(params) {
    return {
        executor: '@nx/vite:preview-server',
        options: {
            buildTarget: `${params.projectName}:build`,
            port: params.previewServerPort,
        },
    };
}
function getTestTarget(params) {
    return {
        executor: '@nx/vite:test',
        outputs: [`${params.offsetFromRoot}coverage/${params.projectRoot}`],
        options: {
            passWithNoTests: true,
            reportsDirectory: `${params.offsetFromRoot}coverage/${params.projectRoot}`,
        },
    };
}
function getServeTarget(params) {
    return {
        executor: '@nx/vite:dev-server',
        options: {
            buildTarget: `${params.projectName}:build.client`,
            mode: 'ssr',
            port: params.devServerPort,
        },
    };
}
function getServeDebugTarget(params) {
    return {
        executor: 'nx:run-commands',
        options: {
            command: `node --inspect-brk ${params.offsetFromRoot}node_modules/vite/bin/vite.js --mode ssr --force`,
            cwd: params.projectRoot,
        },
    };
}
//# sourceMappingURL=get-qwik-application-project-params.js.map