"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.normalizeOptions = void 0;
const devkit_1 = require("@nx/devkit");
const vite_1 = require("vite");
function parseNameWithPath(rawName) {
    const parsedName = (0, vite_1.normalizePath)(rawName).split('/');
    const name = parsedName.pop();
    const path = parsedName.join('/');
    return { name, path };
}
function normalizeNameAndPaths(tree, options) {
    var _a;
    const { root, sourceRoot, projectType } = (0, devkit_1.readProjectConfiguration)(tree, options.project);
    const projectSourceRoot = sourceRoot !== null && sourceRoot !== void 0 ? sourceRoot : (0, devkit_1.joinPathFragments)(root, 'src');
    const { name, path: namePath } = parseNameWithPath(options.name);
    const path = (_a = options.directory) !== null && _a !== void 0 ? _a : (0, devkit_1.joinPathFragments)(projectSourceRoot, projectType === 'application' ? 'components' : 'lib', namePath);
    const directory = options.flat
        ? (0, vite_1.normalizePath)(path)
        : (0, devkit_1.joinPathFragments)(path, name);
    return {
        directory,
        name,
    };
}
function normalizeOptions(host, options) {
    var _a;
    const project = (0, devkit_1.getProjects)(host).get(options.project);
    if (!project) {
        throw new Error(`Cannot find the ${options.project} project. Please double check the project name.`);
    }
    const projectRoot = (_a = project.sourceRoot) !== null && _a !== void 0 ? _a : (0, devkit_1.joinPathFragments)(project.root, 'src');
    const nameAndPath = normalizeNameAndPaths(host, options);
    if (!nameAndPath.directory.startsWith(project.root)) {
        throw new Error(`The provided path "${options.directory}" (resolved as "${nameAndPath.directory}") does not exist under the project root ("${project.root}"). ` +
            `Please make sure to provide a path that exists under the project root.`);
    }
    return Object.assign(Object.assign(Object.assign({}, options), nameAndPath), { hasStyles: options.style !== 'none', projectRoot, exportDefault: !!options.exportDefault });
}
exports.normalizeOptions = normalizeOptions;
//# sourceMappingURL=normalize-options.js.map