"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.addE2eProject = void 0;
const tslib_1 = require("tslib");
const devkit_1 = require("@nx/devkit");
const get_installed_nx_version_1 = require("../../utils/get-installed-nx-version");
const versions_1 = require("../../utils/versions");
const normalize_options_1 = require("./utils/normalize-options");
function addE2eProject(tree, options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const projectConfiguration = (0, devkit_1.readProjectConfiguration)(tree, options.project);
        if (projectConfiguration.projectType !== 'application') {
            throw new Error('Cannot setup e2e project for the given frontend project.');
        }
        const normalizedOptions = (0, normalize_options_1.normalizeOptions)(tree, options);
        if (options.e2eTestRunner === 'cypress') {
            return addCypress(tree, normalizedOptions);
        }
        if (options.e2eTestRunner === 'playwright') {
            return addPlaywright(tree, normalizedOptions);
        }
        return () => void 0;
    });
}
exports.addE2eProject = addE2eProject;
function addCypress(tree, options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        yield (0, devkit_1.ensurePackage)('@nx/cypress', (0, get_installed_nx_version_1.getInstalledNxVersion)(tree));
        const { cypressProjectGenerator } = yield Promise.resolve().then(() => require('@nx/cypress'));
        return yield cypressProjectGenerator(tree, Object.assign(Object.assign({}, options), { name: options.e2eProjectName, directory: options.directory, project: options.project, bundler: 'vite', skipFormat: options.skipFormat }));
    });
}
function addPlaywright(tree, options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        yield (0, devkit_1.ensurePackage)('@nxkit/playwright', versions_1.nxKitVersion);
        const { projectGenerator } = yield Promise.resolve().then(() => require('@nxkit/playwright'));
        return yield projectGenerator(tree, Object.assign(Object.assign({}, options), { name: options.e2eProjectName, directory: options.directory, frontendProject: options.project, skipFormat: options.skipFormat }));
    });
}
exports.default = addE2eProject;
//# sourceMappingURL=generator.js.map