"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.denoIntegrationGenerator = void 0;
const tslib_1 = require("tslib");
const devkit_1 = require("@nx/devkit");
const migrations_1 = require("../../../utils/migrations");
const integration_configuration_name_1 = require("../../../utils/integration-configuration-name");
function validateOptions(tree, options) {
    const config = (0, devkit_1.readProjectConfiguration)(tree, options.project);
    if (config.projectType !== 'application') {
        throw new Error('Cannot setup deno integration for the given project.');
    }
    if (!(0, migrations_1.isQwikNxProject)(config)) {
        throw new Error('Project contains invalid configuration. ' +
            'If you encounter this error within a Qwik project, make sure you have run necessary Nx migrations for qwik-nx plugin.');
    }
}
function normalizeOptions(tree, options) {
    var _a, _b, _c;
    const projectConfig = (0, devkit_1.readProjectConfiguration)(tree, options.project);
    return Object.assign(Object.assign({}, options), { denoProjectName: options.denoProjectName, root: projectConfig.root, offsetFromRoot: (0, devkit_1.offsetFromRoot)(projectConfig.root), config: projectConfig, site: (_a = options.site) !== null && _a !== void 0 ? _a : 'yoursite.dev', denoRoot: (_c = (_b = projectConfig.targets.build.options) === null || _b === void 0 ? void 0 : _b['outputPath']) !== null && _c !== void 0 ? _c : `dist/${projectConfig.root}` });
}
function addFiles(tree, options) {
    const templateOptions = Object.assign(Object.assign({}, (0, devkit_1.names)(options.project)), { projectRoot: options.root, offsetFromRoot: options.offsetFromRoot, site: options.site, denoProjectName: options.denoProjectName, denoRoot: options.denoRoot });
    (0, devkit_1.generateFiles)(tree, (0, devkit_1.joinPathFragments)(__dirname, 'files'), options.root, templateOptions);
    if (options.generateGithubHook) {
        (0, devkit_1.generateFiles)(tree, (0, devkit_1.joinPathFragments)(__dirname, '.github'), '.github', templateOptions);
    }
}
function getBuildSSRTargetDenoConfiguration(options) {
    return {
        configFile: `${options.root}/adapters/deno/vite.config.ts`,
    };
}
function getIntermediateDependsOnTarget(options, configurationName) {
    return {
        executor: 'nx:run-commands',
        options: {
            command: `npx nx run ${options.project}:build:${configurationName}`,
        },
    };
}
function configureProjectTargets(tree, options) {
    var _a, _b;
    var _c, _d;
    const { project, config, denoProjectName, denoRoot } = options;
    // "production" if not yet created, otherwise "deno"
    const configurationName = (0, integration_configuration_name_1.getIntegrationConfigurationName)(integration_configuration_name_1.IntegrationName.Deno, config);
    // build targets
    ((_a = (_c = config.targets['build']).configurations) !== null && _a !== void 0 ? _a : (_c.configurations = {}))[configurationName] = {};
    ((_b = (_d = config.targets['build.ssr']).configurations) !== null && _b !== void 0 ? _b : (_d.configurations = {}))[configurationName] =
        getBuildSSRTargetDenoConfiguration(options);
    config.targets['build-deno'] = getIntermediateDependsOnTarget(options, configurationName);
    // "deploy" if not yet created, otherwise "deno.deploy"
    const deploTargetName = config.targets['deploy'] ? 'deploy.deno' : 'deploy';
    config.targets[deploTargetName] = {
        executor: 'nx:run-commands',
        options: {
            cwd: `${denoRoot}/client`,
            command: `deployctl deploy --project=${denoProjectName} https://deno.land/std/http/file_server.ts --dry-run`,
        },
        configurations: {
            preview: {
                command: `deployctl deploy --project=${denoProjectName} https://deno.land/std/http/file_server.ts`,
            },
            production: {
                command: `deployctl deploy --project=${denoProjectName} --prod https://deno.land/std/http/file_server.ts`,
            },
        },
        dependsOn: ['build-deno'],
    };
    // "preview-deno"
    config.targets['preview-deno'] = {
        executor: 'nx:run-commands',
        options: {
            command: `deno run --allow-net --allow-read --allow-env ${denoRoot}/server/entry.deno.js`,
        },
        dependsOn: ['build-deno'],
    };
    (0, devkit_1.updateProjectConfiguration)(tree, project, config);
}
function denoIntegrationGenerator(tree, options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        validateOptions(tree, options);
        const normalizedOptions = normalizeOptions(tree, options);
        configureProjectTargets(tree, normalizedOptions);
        addFiles(tree, normalizedOptions);
        if (!normalizedOptions.skipFormat) {
            yield (0, devkit_1.formatFiles)(tree);
        }
    });
}
exports.denoIntegrationGenerator = denoIntegrationGenerator;
exports.default = denoIntegrationGenerator;
//# sourceMappingURL=generator.js.map