"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.reactLibraryGenerator = void 0;
const tslib_1 = require("tslib");
const devkit_1 = require("@nx/devkit");
const path = require("path");
const normalize_options_1 = require("./../../library/utils/normalize-options");
const generator_1 = require("../../library/generator");
const init_1 = require("../../../utils/react/init");
function normalizeOptions(tree, options) {
    const normalizedLibraryOptions = (0, normalize_options_1.normalizeOptions)(tree, Object.assign(Object.assign({}, options), { style: 'none' }));
    let targetApps = [];
    if (Array.isArray(options.targetApps)) {
        targetApps = options.targetApps.filter(Boolean);
    }
    else if (typeof options.targetApps === 'string' &&
        options.targetApps.trim()) {
        // can be of type "string" if value comes from the x-prompt
        targetApps = options.targetApps
            .split(',')
            .map((v) => v.trim())
            .filter(Boolean);
    }
    return Object.assign(Object.assign({}, normalizedLibraryOptions), { installMUIExample: options.installMUIExample !== false, targetApps });
}
function addFiles(tree, options) {
    (0, devkit_1.generateFiles)(tree, path.join(__dirname, 'files'), options.projectRoot, options);
}
function updateTargetApps(tree, targetApps) {
    if (!(targetApps === null || targetApps === void 0 ? void 0 : targetApps.length)) {
        devkit_1.output.warn({
            title: `You haven't provided any "targetApps" to be configured.`,
            bodyLines: [
                'Qwik React integration requires "qwikReact()" plugin to be included for all apps where qwikified react components are used.',
                'You can still import the plugin manually.',
            ],
        });
    }
    else {
        for (const targetApp of new Set(targetApps)) {
            const config = (0, devkit_1.readProjectConfiguration)(tree, targetApp);
            if (config.projectType !== 'application') {
                throw new Error(`"${targetApp}" project is not an application`);
            }
            (0, init_1.addReactPluginToViteConfig)(tree, config.root);
        }
    }
}
function reactLibraryGenerator(tree, schema) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const normalizedOptions = normalizeOptions(tree, schema);
        const tasks = [];
        const installTask = yield (0, generator_1.default)(tree, Object.assign(Object.assign({}, normalizedOptions), { skipFormat: true, generateComponent: false }));
        tasks.push(installTask);
        const initTask = (0, init_1.reactInit)(tree, {
            demoFilePath: (0, devkit_1.joinPathFragments)(normalizedOptions.projectRoot, 'src/lib/integration'),
            installMUIExample: !!normalizedOptions.installMUIExample,
            projectRoot: normalizedOptions.projectRoot,
        });
        tasks.push(initTask);
        addFiles(tree, normalizedOptions);
        updateTargetApps(tree, normalizedOptions.targetApps);
        if (!normalizedOptions.skipFormat) {
            yield (0, devkit_1.formatFiles)(tree);
        }
        return (0, devkit_1.runTasksInSerial)(...tasks);
    });
}
exports.reactLibraryGenerator = reactLibraryGenerator;
exports.default = reactLibraryGenerator;
//# sourceMappingURL=generator.js.map