"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.routeGenerator = void 0;
const tslib_1 = require("tslib");
const devkit_1 = require("@nx/devkit");
const path = require("path");
exports.default = routeGenerator;
function routeGenerator(tree, options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const normalizedOptions = normalizeOptions(tree, options);
        addFiles(tree, normalizedOptions);
        yield (0, devkit_1.formatFiles)(tree);
    });
}
exports.routeGenerator = routeGenerator;
function normalizeOptions(tree, options) {
    var _a;
    const name = (0, devkit_1.names)(options.name).fileName;
    const project = (0, devkit_1.getProjects)(tree).get(options.project);
    if (!project) {
        devkit_1.logger.error(`Cannot find the ${options.project} project. Please double check the project name.`);
        throw new Error();
    }
    const routeDirectory = options.directory
        ? `${(0, devkit_1.names)(options.directory).fileName}/${name}`
        : name;
    const routeName = name;
    return Object.assign(Object.assign({}, options), { routeName, projectSourceRoot: (_a = project.sourceRoot) !== null && _a !== void 0 ? _a : (0, devkit_1.joinPathFragments)(project.root, 'src'), routeDirectory });
}
function addFiles(tree, options) {
    const templateOptions = Object.assign(Object.assign(Object.assign({}, options), (0, devkit_1.names)(options.name)), { routeName: (0, devkit_1.names)(options.name).fileName, offsetFromRoot: (0, devkit_1.offsetFromRoot)(options.projectSourceRoot), template: '' });
    const routesFolder = `${options.projectSourceRoot}/routes`;
    generateFilesByType('route');
    if (options.addLayout) {
        generateFilesByType('layout');
    }
    function generateFilesByType(fileType) {
        (0, devkit_1.generateFiles)(tree, path.join(__dirname, `files/${fileType}`), routesFolder, templateOptions);
    }
}
//# sourceMappingURL=generator.js.map