"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.storybookConfigurationGenerator = void 0;
const tslib_1 = require("tslib");
const devkit_1 = require("@nx/devkit");
const linter_1 = require("@nx/linter");
const path = require("path");
const ensure_file_utils_1 = require("../../utils/ensure-file-utils");
const get_installed_nx_version_1 = require("../../utils/get-installed-nx-version");
const versions_1 = require("../../utils/versions");
function addFiles(tree, options, { root }) {
    tree.delete(path.join(root, '.storybook/main.js'));
    const templateOptions = Object.assign(Object.assign(Object.assign({}, options), (0, devkit_1.names)(options.name)), { offsetFromRoot: (0, devkit_1.offsetFromRoot)(root), projectRoot: root, configExtension: options.tsConfiguration ? 'ts' : 'js' });
    (0, devkit_1.generateFiles)(tree, path.join(__dirname, 'files'), root, templateOptions);
    (0, ensure_file_utils_1.ensureRootTsxExists)(tree, options.name);
    (0, ensure_file_utils_1.ensureMdxTypeInTsConfig)(tree, options.name);
}
function normalizeOptions(options, projectConfig) {
    var _a, _b;
    let qwikCitySupportInternal;
    if (options.qwikCitySupport === 'auto' || !options.qwikCitySupport) {
        // "auto"
        qwikCitySupportInternal = projectConfig.projectType === 'application';
    }
    else {
        // "true" or "false"
        qwikCitySupportInternal = options.qwikCitySupport === 'true';
    }
    return Object.assign(Object.assign({}, options), { js: !!options.js, linter: (_a = options.linter) !== null && _a !== void 0 ? _a : linter_1.Linter.EsLint, tsConfiguration: (_b = options.tsConfiguration) !== null && _b !== void 0 ? _b : true, qwikCitySupportInternal });
}
function storybookConfigurationGenerator(tree, options) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const projectConfig = (0, devkit_1.readProjectConfiguration)(tree, options.name);
        const normalizedOptions = normalizeOptions(options, projectConfig);
        const nxVersion = (0, get_installed_nx_version_1.getInstalledNxVersion)(tree);
        (0, devkit_1.ensurePackage)('@nx/storybook', nxVersion);
        const { configurationGenerator } = yield Promise.resolve().then(() => require('@nx/storybook'));
        const { oldFormat } = yield getStorybookVersion();
        yield configurationGenerator(tree, {
            storybook7UiFramework: '@storybook/html-webpack5',
            // eslint-disable-next-line @typescript-eslint/ban-ts-comment
            // @ts-ignore
            uiFramework: oldFormat ? '@storybook/html' : '@storybook/html-webpack5',
            bundler: 'vite',
            name: normalizedOptions.name,
            js: normalizedOptions.js,
            linter: normalizedOptions.linter,
            tsConfiguration: normalizedOptions.tsConfiguration,
            storybook7Configuration: true,
            configureCypress: false,
        });
        addFiles(tree, normalizedOptions, projectConfig);
        yield (0, devkit_1.formatFiles)(tree);
        return addStorybookDependencies(tree);
    });
}
exports.storybookConfigurationGenerator = storybookConfigurationGenerator;
function addStorybookDependencies(tree) {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const { storybookVersion } = yield getStorybookVersion();
        return (0, devkit_1.addDependenciesToPackageJson)(tree, {}, {
            'storybook-framework-qwik': versions_1.storybookFrameworkQwikVersion,
            '@storybook/builder-vite': storybookVersion,
            '@storybook/addon-docs': storybookVersion,
            react: versions_1.reactVersion,
            'react-dom': versions_1.reactDOMVersion,
            '@types/mdx': versions_1.typesMdx,
        });
    });
}
function getStorybookVersion() {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        // eslint-disable-next-line @typescript-eslint/ban-ts-comment
        // @ts-ignore "storybook7Version" was renamed to "storybookVersion" in nx16.1. Leaving both for compatibility
        const { storybook7Version, storybookVersion } = yield Promise.resolve().then(() => require('@nx/storybook/src/utils/versions'));
        const oldFormat = !!storybook7Version;
        return {
            oldFormat,
            storybookVersion: oldFormat ? storybook7Version : storybookVersion,
        };
    });
}
exports.default = storybookConfigurationGenerator;
//# sourceMappingURL=generator.js.map