"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.filterProjects = void 0;
function filterProjects(projects, filterConfig, exclusive) {
    var _a;
    if (filterConfig === null || filterConfig === void 0 ? void 0 : filterConfig.name) {
        projects = filterProjectsByName(projects, filterConfig.name, exclusive);
    }
    if (filterConfig === null || filterConfig === void 0 ? void 0 : filterConfig.path) {
        projects = filterProjectsByPath(projects, filterConfig.path, exclusive);
    }
    if ((_a = filterConfig === null || filterConfig === void 0 ? void 0 : filterConfig.tags) === null || _a === void 0 ? void 0 : _a.length) {
        projects = filterProjectsByTags(projects, filterConfig.tags, exclusive);
    }
    if (typeof (filterConfig === null || filterConfig === void 0 ? void 0 : filterConfig.customFilter) === 'function') {
        projects = projects.filter((p) => {
            const matches = filterConfig.customFilter(p);
            return exclusive ? !matches : matches;
        });
    }
    return projects;
}
exports.filterProjects = filterProjects;
function filterProjectsByName(projects, options, exclusive) {
    if (Array.isArray(options)) {
        const optionsSet = new Set(options);
        return projects.filter((p) => {
            const matches = optionsSet.has(p.name);
            return exclusive ? !matches : matches;
        });
    }
    else if (options instanceof RegExp) {
        return filterByRegex(projects, options, exclusive, (p) => p.name);
    }
    return projects;
}
function filterProjectsByPath(projects, options, exclusive) {
    if (options instanceof RegExp) {
        return filterByRegex(projects, options, exclusive, (p) => p.sourceRoot);
    }
    return projects;
}
function filterByRegex(projects, options, exclusive, valueGetter) {
    if (options instanceof RegExp) {
        if (options.global) {
            console.log(`"global" flag has been removed from the RegExp ${options}`);
            options = new RegExp(options.source, options.flags.replace('g', ''));
        }
        return projects.filter((p) => {
            const matches = options.test(valueGetter(p));
            return exclusive ? !matches : matches;
        });
    }
    return projects;
}
function filterProjectsByTags(projects, tags, exclusive) {
    if (exclusive) {
        return projects.filter((p) => {
            return tags.every((t) => { var _a; return !((_a = p.tags) === null || _a === void 0 ? void 0 : _a.includes(t)); });
        });
    }
    else {
        return projects.filter((p) => {
            return tags.every((t) => { var _a; return (_a = p.tags) === null || _a === void 0 ? void 0 : _a.includes(t); });
        });
    }
}
//# sourceMappingURL=filter-projects.js.map