"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getVendorRoots = void 0;
const tslib_1 = require("tslib");
const file_utils_1 = require("nx/src/project-graph/file-utils");
const fs_1 = require("fs");
const path_1 = require("path");
const devkit_1 = require("@nx/devkit");
const current_project_name_1 = require("./current-project-name");
const filter_projects_1 = require("./filter-projects");
const get_project_dependencies_1 = require("./get-project-dependencies");
/** Retrieves vendor roots and applies necessary filtering */
function getVendorRoots(options, qwikOptions) {
    var _a, _b;
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const log = (...str) => {
            ((options === null || options === void 0 ? void 0 : options.debug) || qwikOptions.debug) &&
                console.debug(`[QWIK-NX-VITE PLUGIN:]`, ...str);
        };
        const workspaceConfig = (0, file_utils_1.readWorkspaceConfig)({ format: 'nx' });
        const baseTsConfig = JSON.parse((0, fs_1.readFileSync)((0, path_1.join)(devkit_1.workspaceRoot, 'tsconfig.base.json')).toString());
        const decoratedPaths = Object.values(baseTsConfig.compilerOptions.paths).flat();
        let projects = Object.values(workspaceConfig.projects);
        if ((options === null || options === void 0 ? void 0 : options.currentProjectName) &&
            !workspaceConfig.projects[options.currentProjectName]) {
            throw new Error(`Could not find project with name "${options.currentProjectName}"`);
        }
        const currentProjectName = (_a = options === null || options === void 0 ? void 0 : options.currentProjectName) !== null && _a !== void 0 ? _a : (0, current_project_name_1.getCurrentProjectName)(workspaceConfig, qwikOptions.rootDir);
        projects = projects.filter((p) => p.name !== currentProjectName);
        if (!((_b = options === null || options === void 0 ? void 0 : options.excludeProjects) === null || _b === void 0 ? void 0 : _b.keepUnrelatedProjects)) {
            // by default including only project dependencies
            const dependencies = yield (0, get_project_dependencies_1.getProjectDependencies)(currentProjectName);
            projects = projects.filter((p) => dependencies.has(p.name));
            if (options === null || options === void 0 ? void 0 : options.debug) {
                log(`Dependencies for "${currentProjectName}":`, projects.map((p) => p.name));
            }
        }
        projects.forEach((p) => { var _a; return ((_a = p.sourceRoot) !== null && _a !== void 0 ? _a : (p.sourceRoot = p.root)); });
        projects = (0, filter_projects_1.filterProjects)(projects, options === null || options === void 0 ? void 0 : options.excludeProjects, true);
        projects = (0, filter_projects_1.filterProjects)(projects, options === null || options === void 0 ? void 0 : options.includeProjects, false);
        if (options === null || options === void 0 ? void 0 : options.debug) {
            log('Projects after applying include\\exclude filters:', projects.map((p) => p.name));
        }
        projects = projects.filter((p) => decoratedPaths.some((path) => path.startsWith(p.sourceRoot)));
        if (options === null || options === void 0 ? void 0 : options.debug) {
            log('Projects after excluding those not in tsconfig.base.json:', projects.map((p) => p.name));
        }
        return projects.map((p) => p.sourceRoot).map((p) => (0, path_1.join)(devkit_1.workspaceRoot, p));
    });
}
exports.getVendorRoots = getVendorRoots;
//# sourceMappingURL=get-vendor-roots.js.map