"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.configureEslint = void 0;
const devkit_1 = require("@nx/devkit");
const linter_1 = require("@nx/linter");
const versions_1 = require("./versions");
function configureEslint(tree, project, skipLibsEslintConfig = false) {
    var _a, _b;
    const cfg = (0, devkit_1.readProjectConfiguration)(tree, project);
    const existingLibEslintConfigPath = (0, devkit_1.joinPathFragments)(cfg.root, '.eslintrc.json');
    let existingLibEslintConfig;
    if (tree.exists(existingLibEslintConfigPath)) {
        existingLibEslintConfig = tree.read(existingLibEslintConfigPath);
    }
    (0, linter_1.lintProjectGenerator)(tree, {
        project: project,
        linter: linter_1.Linter.EsLint,
        skipFormat: true,
        eslintFilePatterns: [`${cfg.root}/**/*.{ts,tsx,js,jsx}`],
    });
    if (existingLibEslintConfig && skipLibsEslintConfig) {
        tree.write(existingLibEslintConfigPath, existingLibEslintConfig);
    }
    const viteConfigFileName = 'vite.config.ts';
    const eslintIgnorePath = './.eslintignore';
    let eslintIgnore = '';
    if (tree.exists(eslintIgnorePath)) {
        eslintIgnore = (_b = (_a = tree.read(eslintIgnorePath)) === null || _a === void 0 ? void 0 : _a.toString()) !== null && _b !== void 0 ? _b : '';
    }
    if (!eslintIgnore.includes(viteConfigFileName)) {
        tree.write(eslintIgnorePath, (eslintIgnore + `\n${viteConfigFileName}`).trim());
    }
    return (0, devkit_1.addDependenciesToPackageJson)(tree, {}, {
        'eslint-plugin-qwik': versions_1.qwikEslintPluginVersion,
    });
}
exports.configureEslint = configureEslint;
//# sourceMappingURL=configure-eslint.js.map