"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.reactInit = exports.addReactPluginToViteConfig = void 0;
const devkit_1 = require("@nx/devkit");
const path = require("path");
const versions_1 = require("../versions");
const update_vite_config_1 = require("../update-vite-config");
const vite_1 = require("@nx/vite");
function addFiles(tree, options, mui) {
    (0, devkit_1.generateFiles)(tree, path.join(__dirname, 'files', mui ? 'mui' : 'demo'), options.demoFilePath, {});
}
function addDependencies(tree, mui) {
    const devDependencies = {
        '@builder.io/qwik-react': versions_1.qwikReactVersion,
        '@emotion/react': versions_1.emotionReactVersion,
        '@emotion/styled': versions_1.emotionStyledVersion,
        '@types/react': versions_1.typesReactVersion,
        '@types/react-dom': versions_1.typesReactDOMVersion,
        react: versions_1.reactVersion,
        'react-dom': versions_1.reactDOMVersion,
    };
    if (mui) {
        Object.assign(devDependencies, {
            '@mui/material': versions_1.muiMaterialVersion,
            '@mui/x-data-grid': versions_1.muiDataGridVersion,
        });
    }
    return (0, devkit_1.addDependenciesToPackageJson)(tree, {}, devDependencies);
}
function addReactPluginToViteConfig(tree, projectRoot) {
    const viteConfigPath = (0, vite_1.normalizeViteConfigFilePathWithTree)(tree, projectRoot);
    if (!viteConfigPath) {
        throw new Error(`Could not resolve vite config at ${projectRoot}`);
    }
    const viteConfig = tree.read(viteConfigPath).toString();
    const updatedViteConfig = (0, update_vite_config_1.updateViteConfig)(viteConfig, {
        imports: [
            {
                namedImports: ['qwikReact'],
                importPath: '@builder.io/qwik-react/vite',
            },
        ],
        vitePlugins: ['qwikReact()'],
    });
    tree.write(viteConfigPath, updatedViteConfig);
}
exports.addReactPluginToViteConfig = addReactPluginToViteConfig;
/**
 * - adds react example component (either MUI or plain react one)
 * - installs neccessary dependencies
 */
function reactInit(tree, options) {
    addFiles(tree, options, !!options.installMUIExample);
    addReactPluginToViteConfig(tree, options.projectRoot);
    return addDependencies(tree, !!options.installMUIExample);
}
exports.reactInit = reactInit;
//# sourceMappingURL=init.js.map